@@ -187,7 +187,7 @@ foreach my $method (qw(wait_all wait_any needs_all needs_any)) {
     };
 }
 
-our $VERSION = '0.020';
+our $VERSION = '0.030';
 
 1;
 
@@ -199,7 +199,7 @@ Future::Q - a thenable Future like Q module for JavaScript
 
 =head1 VERSION
 
-Version 0.020
+Version 0.030
 
 =head1 SYNOPSIS
 
@@ -414,9 +414,9 @@ Below is the detailed specification of C<then()> method.
 
 C<$on_fulfilled> and C<$on_rejected> are subroutine references.
 When C<$future> is fulfilled, C<$on_fulfilled> callback is executed.
-Its arguments are the values of the C<$future> obtained by C<< $future->get >> method.
+Its arguments are the values of the C<$future>, which are obtained by C<< $future->get >> method.
 When C<$future> is rejected, C<$on_rejected> callback is executed.
-Its arguments are the reason of the failure obtained by C<< $future->failure >> method.
+Its arguments are the reason of the failure, which are obtained by C<< $future->failure >> method.
 Both C<$on_fulfilled> and C<$on_rejected> are optional.
 
 C<$next_future> is a new L<Future::Q> object.
@@ -565,7 +565,7 @@ Returns true if the C<$future> is rejected. It returns false otherwise.
 =head1 DIFFERENCE FROM Q
 
 Although L<Future::Q> tries to emulate the behavior of Q module for JavaScript as much as possible,
-there is difference in some repects.
+there is difference in some respects.
 
 =over
 
@@ -619,15 +619,19 @@ There is no corresponding method in this version of L<Future::Q>.
 Its class method form is enough to get the job done.
 Use C<< Future::Q->fcall() >>.
 
-=item promise.all(), promise.allResolve()
+=item promise.all(), promise.allResolve(), promise.allSettled()
 
-Use C<< Future::Q->needs_all() >> and C<< Future::Q->wait_all() >> methods, respectively.
+Use C<< Future::Q->needs_all() >> and C<< Future::Q->wait_all() >> methods inherited from the original L<Future> class.
 
 =item deferred.resolve()
 
 This is an interesting method, but it's not supported in this version of L<Future::Q>.
 Call C<fulfill()> or C<reject()> explicitly instead.
 
+=item Q()
+
+Use C<< Future::Q->wrap() >> method inherited from the original L<Future> class.
+
 =back
 
 
